@@ -63,3 +63,21 @@ my only friend"""
 		"FIN":        "Here is the end,\nmy only friend",
 	}, secrets)
 }
+
+func Test_parse_with_comma(t *testing.T) {
+	reader := strings.NewReader("FOO=BAR,BAZ")
+	secrets, err := parseSecrets(reader)
+	assert.NoError(t, err)
+	assert.Equal(t, map[string]string{
+		"FOO": "BAR,BAZ",
+	}, secrets)
+}
+
+func Test_parse_with_equal(t *testing.T) {
+	reader := strings.NewReader("FOO=BAR BAZ")
+	secrets, err := parseSecrets(reader)
+	assert.NoError(t, err)
+	assert.Equal(t, map[string]string{
+		"FOO": "BAR BAZ",
+	}, secrets)
+}
